==> bouml_2.17.1.tar.gz: bouml_2.17.1/src/data/ActivityObjectData.cpp <==
// *************************************************************************
//
// Copyright (C) 2004-2006 Bruno PAGES  All rights reserved.
//
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifdef WIN32
#pragma warning (disable: 4150)
#endif

#include <qcursor.h>

#include "ActivityObjectData.h"
#include "ActivityObjectDialog.h"
#include "BrowserClass.h"
#include "myio.h"
#include "ToolCom.h"
#include "mu.h"

ActivityObjectData::ActivityObjectData() {
}

ActivityObjectData::ActivityObjectData(ActivityObjectData * model, BrowserNode * bn)
    : SimpleData(model), ObjectData(model) {
  browser_node = bn;
}

void ActivityObjectData::edit(const char * what, QStringList & st) {
  setName(browser_node->get_name());
    
  (new ActivityObjectDialog(this, what, st, QCursor::pos()))->show();
}

void ActivityObjectData::send_uml_def(ToolCom * com, BrowserNode * bn,
				      const QString & comment) {
  BasicData::send_uml_def(com, bn, comment);  
  ObjectData::send_uml_def(com);
}

void ActivityObjectData::set_type(BrowserClass * c) {
  if (type.type != c) {
    if (type.type != 0)
      disconnect(type.type->get_data(), SIGNAL(changed()), this, SLOT(modified()));
    connect(c->get_data(), SIGNAL(changed()), this, SLOT(modified()));
    type.explicit_type = 0;
    type.type = c;
  }
}

void ActivityObjectData::set_type(const AType & t) {
  if (t.type != 0)
    set_type(t.type);
  else {
    if (type.type != 0) {
      disconnect(type.type->get_data(), SIGNAL(changed()), this, SLOT(modified()));
      type.type = 0;
    }
    type.explicit_type = t.explicit_type;
  }
}

bool ActivityObjectData::tool_cmd(ToolCom * com, const char * args,
				  BrowserNode * bn,
				  const QString & comment) {
  if (((unsigned char) args[-1]) >= firstSetCmd) {
    if (!bn->is_writable() && !root_permission())
      com->write_ack(FALSE);
    else if (! ObjectData::tool_cmd(com, args))
      return BasicData::tool_cmd(com, args, bn, comment);
  }
  else if (! ObjectData::tool_cmd(com, args))
    return BasicData::tool_cmd(com, args, bn, comment);
      
  // ok case
  bn->modified();
  bn->package_modified();
  modified();
  com->write_ack(TRUE);
  return TRUE;
}

void ActivityObjectData::save(QTextStream & st, QString & warning, QString what) const {
  BasicData::save(st, warning);
  nl_indent(st);
  ObjectData::save(st, warning,
		   what + " <b>" + browser_node->full_name() + "</b>");
}

void ActivityObjectData::read(char * & st, char * & k) {
  BasicData::read(st, k);	// updates k
  ObjectData::read(st, k);	// updates k
  
  if (type.type != 0)
    connect(type.type->get_data(), SIGNAL(changed()), this, SLOT(modified()));
}

==> bouml_2.19.2.orig.tar.gz: bouml_2.19.2/src/data/ActivityObjectData.cpp <==
// *************************************************************************
//
// Copyright (C) 2004-2006 Bruno PAGES  All rights reserved.
//
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifdef WIN32
#pragma warning (disable: 4150)
#endif

#include <qcursor.h>

#include "ActivityObjectData.h"
#include "ActivityObjectDialog.h"
#include "BrowserClass.h"
#include "myio.h"
#include "ToolCom.h"
#include "mu.h"

ActivityObjectData::ActivityObjectData() {
}

ActivityObjectData::ActivityObjectData(ActivityObjectData * model, BrowserNode * bn)
    : SimpleData(model), ObjectData(model) {
  browser_node = bn;
}

void ActivityObjectData::edit(const char * what, QStringList & st) {
  setName(browser_node->get_name());
    
  (new ActivityObjectDialog(this, what, st))->show();
}

void ActivityObjectData::send_uml_def(ToolCom * com, BrowserNode * bn,
				      const QString & comment) {
  BasicData::send_uml_def(com, bn, comment);  
  ObjectData::send_uml_def(com);
}

void ActivityObjectData::send_cpp_def(ToolCom * com) {
  ObjectData::send_cpp_def(com);
}

void ActivityObjectData::send_java_def(ToolCom * com) {
  ObjectData::send_java_def(com);
}

void ActivityObjectData::set_type(BrowserClass * c) {
  if (type.type != c) {
    if (type.type != 0)
      disconnect(type.type->get_data(), SIGNAL(changed()), this, SLOT(modified()));
    connect(c->get_data(), SIGNAL(changed()), this, SLOT(modified()));
    type.explicit_type = 0;
    type.type = c;
  }
}

void ActivityObjectData::set_type(const AType & t) {
  if (t.type != 0)
    set_type(t.type);
  else {
    if (type.type != 0) {
      disconnect(type.type->get_data(), SIGNAL(changed()), this, SLOT(modified()));
      type.type = 0;
    }
    type.explicit_type = t.explicit_type;
  }
}

bool ActivityObjectData::tool_cmd(ToolCom * com, const char * args,
				  BrowserNode * bn,
				  const QString & comment) {
  if (((unsigned char) args[-1]) >= firstSetCmd) {
    if (!bn->is_writable() && !root_permission())
      com->write_ack(FALSE);
    else if (! ObjectData::tool_cmd(com, args))
      return BasicData::tool_cmd(com, args, bn, comment);
  }
  else if (! ObjectData::tool_cmd(com, args))
    return BasicData::tool_cmd(com, args, bn, comment);
      
  // ok case
  bn->modified();
  bn->package_modified();
  modified();
  com->write_ack(TRUE);
  return TRUE;
}

void ActivityObjectData::save(QTextStream & st, QString & warning, QString what) const {
  BasicData::save(st, warning);
  nl_indent(st);
  ObjectData::save(st, warning,
		   what + " <b>" + browser_node->full_name() + "</b>");
}

void ActivityObjectData::read(char * & st, char * & k) {
  BasicData::read(st, k);	// updates k
  ObjectData::read(st, k);	// updates k
  
  if (type.type != 0)
    connect(type.type->get_data(), SIGNAL(changed()), this, SLOT(modified()));
}
